package LATMOS::Accounts::Bases::Sql::Groupofnames;

use 5.010000;
use strict;
use warnings;
use overload '""' => 'stringify';

use base qw(LATMOS::Accounts::Bases::Sql::Group);
use LATMOS::Accounts::Log;
use LATMOS::Accounts::I18N;

our $VERSION = (q$Rev: 1920 $ =~ /^Rev: (\d+) /)[0];

=head1 NAME

LATMOS::Accounts::Bases::Sql::Group - Groups objects support

=cut

sub stringify {
    my ($self) = @_;

    $self->get_field('label')
    || $self->id;
}

sub _object_table { 'group' }

sub _key_field { 'name' }

sub _has_extended_attributes { 1 }

sub listReal {
    my ($class, $base) = @_;

    my $sth = $base->db->prepare_cached(
        sprintf(
            q{select name as k from "group" where oalias IS NULL and internobject = false %s
              and ikey in (
                SELECT okey from group_attributes_users
                join "user" on group_attributes_users.value = "user".name
                where attr = 'memberUID' %s
                )
              order by name
            },
            ($base->{wexported} ? '' : 'and exported = true'),
            ($base->{wexported} ? '' : 'and "user".exported = true'),
        )
    );
    $sth->execute;
    my @keys;
    while(my $res = $sth->fetchrow_hashref) {
        push(@keys, $res->{k});
    }
    @keys
}

sub list {
    my ($class, $base) = @_;

    my $sth = $base->db->prepare_cached(
        sprintf(
            q{select name as k from "group" where internobject = false %s
              and ikey in (
                SELECT okey from group_attributes_users
                join "user" on group_attributes_users.value = "user".name
                where attr = 'memberUID' %s
                )
              order by name
            },
            ($base->{wexported} ? '' : 'and exported = true'),
            ($base->{wexported} ? '' : 'and "user".exported = true'),
        )
    );
    $sth->execute;
    my @keys;
    while(my $res = $sth->fetchrow_hashref) {
        push(@keys, $res->{k});
    }
    @keys
}

sub list_from_rev {
    my ($class, $base, $rev) = @_;
    my $sth = $base->db->prepare_cached(
        sprintf(
            q{select name as k from "group" where internobject = false %s
              and rev > ? and oalias IS NULL
              and ikey in (
                SELECT okey from group_attributes_users
                join "user" on group_attributes_users.value = "user".name
                where attr = 'memberUID' %s
                )
              order by name
            },
            ($base->{wexported} ? '' : 'and exported = true'),
            ($base->{wexported} ? '' : 'and "user".exported = true'),
        )
    );
    $sth->execute($rev);
    my @keys;
    while(my $res = $sth->fetchrow_hashref) {
        push(@keys, $res->{k});
    }
    @keys
}

sub _get_attr_schema {
    my ($class, $base) = @_;

    my $Attrs = $class->SUPER::_get_attr_schema( $base );
    foreach (keys %$Attrs) {
        $Attrs->{$_}->{ro} = 1;
    }

    return $Attrs;
}

1;

__END__

=head1 SEE ALSO

L<LATMOS::Accounts::Bases::Sql>

=head1 AUTHOR

Olivier Thauvin, E<lt>olivier.thauvin@latmos.ipsl.frE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2008, 2009 CNRS SA/CETP/LATMOS

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.10.0 or,
at your option, any later version of Perl 5 you may have available.

=cut
